@@ -1,8 +1,8 @@
 __title__ = 'Dick.py'
-__author__ = 'bakugo'
+__author__ = 'Bakugo'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Slimakoi'
-__version__ = '1.2.13'
+__version__ = '1.3.1'
 
 from .acm import ACM
 from .client import Client
